/* -*-c-*-
 *
 * Identifies and logs the client of a connection
 *
 * (c) 1999 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of the `fw' port forwarder.
 *
 * `fw' is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * `fw' is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with `fw'; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef IDENTIFY_H
#define IDENTIFY_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Header files ------------------------------------------------------*/

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>

#ifndef REFFD_H
#  include "reffd.h"
#endif

/*----- Data structures ---------------------------------------------------*/

typedef struct id_req {
  struct sockaddr_in lsin;		/* Local address of connection */
  struct sockaddr_in rsin;		/* Remote address of connection */
  const char *desc;			/* Description of connection */
  const char *act;			/* Action taken by server */
  reffd *r;				/* Pointer to file descriptor */
} id_req;

/*----- Functions provided ------------------------------------------------*/

/* --- @identify@ --- *
 *
 * Arguments:	@const id_req *q@ = pointer to request block
 *
 * Returns:	---
 *
 * Use:		Starts a background ident lookup and reverse-resolve job
 *		which will, eventually, report a message to the system log.
 */

extern void identify(const id_req */*q*/);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
